@@ -1,7 +1,7 @@
 import errno
 import logging
 import os
-from threading import Thread
+from threading import Thread, RLock
 import time
 import sys
 
@@ -10,12 +10,14 @@ from zmq.eventloop import ioloop
 
 from circus.controller import Controller
 from circus.exc import AlreadyExist
-from circus.flapping import Flapping
 from circus import logger
 from circus.watcher import Watcher
 from circus.util import debuglog, _setproctitle
 from circus.config import get_config
 
+# will be imported by plugin registration later XXX
+from circus.plugins.flapping import Flapping
+
 
 class Arbiter(object):
     """Class used to control a list of watchers.
@@ -56,7 +58,7 @@ class Arbiter(object):
         self.pid = os.getpid()
         self._watchers_names = {}
         self.alive = True
-        self.busy = False
+        self._lock = RLock()
         self.check_flapping = check_flapping
 
         # initializing circusd-stats as a watcher when configured
@@ -193,8 +195,10 @@ class Arbiter(object):
                     raise
 
     def manage_watchers(self):
-        if not self.busy and self.alive:
-            self.busy = True
+        if not self.alive:
+            return
+
+        with self._lock:
             # manage and reap processes
             self.reap_processes()
             for watcher in self.iter_watchers():
@@ -202,12 +206,10 @@ class Arbiter(object):
 
             if self.check_flapping and not self.flapping.is_alive():
                 self.flapping = Flapping(self.context, self.endpoint,
-                                         self.pubsub_endpoint,
-                                         self.check_delay)
+                                            self.pubsub_endpoint,
+                                            self.check_delay)
                 self.flapping.start()
 
-            self.busy = False
-
     @debuglog
     def reload(self, graceful=True):
         """Reloads everything.
