@@ -32,6 +32,8 @@ class Refresher(Thread):
         self.running = True
         while self.running:
             for watcher, pid, stat in self.cclient:
+                if not self.running:
+                    break
                 if watcher == 'circus':
                     data = dstats
                 else:
